# Text Augmenter

Text Augmenter is a Python package for augmenting text data directly on your pandas dataframe using various NLP techniques. 
There are only 3 techniques now : 
- augment_random_word
- augment_random_character
- augment_word_bert

### augment_random_word


## Installation

```bash
pip install text_augmenter
